//
//  ProgressView.m
//  timerCount
//
//  Created by Hans De Smedt on 18/02/13.
//  Copyright (c) 2013 Hans De Smedt. All rights reserved.
//

#import "ProgressView.h"

@implementation ProgressView

- (id)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        // Initialization code
    }
    return self;
}


// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.
- (void)drawRect:(CGRect)rect
{
    //// General Declarations
    CGColorSpaceRef colorSpace = CGColorSpaceCreateDeviceRGB();
    CGContextRef context = UIGraphicsGetCurrentContext();
    
    //// Color Declarations
    UIColor* innerCircleColor = [UIColor colorWithRed: 0 green: 0.513 blue: 0.983 alpha: 1];
    UIColor* innerCircleColor2 = [UIColor colorWithRed: 0 green: 0.649 blue: 0.982 alpha: 1];
    CGFloat innerCircleColor2RGBA[4];
    [innerCircleColor2 getRed: &innerCircleColor2RGBA[0] green: &innerCircleColor2RGBA[1] blue: &innerCircleColor2RGBA[2] alpha: &innerCircleColor2RGBA[3]];
    
    UIColor* borderCircle = [UIColor colorWithRed: (innerCircleColor2RGBA[0] * 0.4 + 0.6) green: (innerCircleColor2RGBA[1] * 0.4 + 0.6) blue: (innerCircleColor2RGBA[2] * 0.4 + 0.6) alpha: (innerCircleColor2RGBA[3] * 0.4 + 0.6)];
    UIColor* outerBackgroundColor = [UIColor colorWithRed: 0 green: 0.543 blue: 0.964 alpha: 1];
    UIColor* outerBackgroundColor2 = [UIColor colorWithRed: 0 green: 0.673 blue: 0.992 alpha: 1];
    
    //// Gradient Declarations
    NSArray* backgroundColors = [NSArray arrayWithObjects:
                                 (id)outerBackgroundColor2.CGColor,
                                 (id)outerBackgroundColor.CGColor, nil];
    CGFloat backgroundLocations[] = {0, 1};
    CGGradientRef background = CGGradientCreateWithColors(colorSpace, (__bridge CFArrayRef)backgroundColors, backgroundLocations);
    
    //// Shadow Declarations
    UIColor* shadow = innerCircleColor;
    CGSize shadowOffset = CGSizeMake(4.1, 8.1);
    CGFloat shadowBlurRadius = 25;
    

    
    
    //// Rectangle Drawing
    CGRect rectangleRect = CGRectMake(CGRectGetMinX(rect), CGRectGetMinY(rect), CGRectGetWidth(rect), CGRectGetHeight(rect));
    UIBezierPath* rectanglePath = [UIBezierPath bezierPathWithRect: rectangleRect];
    CGContextSaveGState(context);
    [rectanglePath addClip];
    CGFloat rectangleResizeRatio = MIN(CGRectGetWidth(rectangleRect) / 239, CGRectGetHeight(rectangleRect) / 243);
    CGContextDrawRadialGradient(context, background,
                                CGPointMake(CGRectGetMidX(rectangleRect) + 0 * rectangleResizeRatio, CGRectGetMidY(rectangleRect) + -0 * rectangleResizeRatio), 55.31 * rectangleResizeRatio,
                                CGPointMake(CGRectGetMidX(rectangleRect) + 0 * rectangleResizeRatio, CGRectGetMidY(rectangleRect) + -0 * rectangleResizeRatio), 120.43 * rectangleResizeRatio,
                                kCGGradientDrawsBeforeStartLocation | kCGGradientDrawsAfterEndLocation);
    CGContextRestoreGState(context);
    [[UIColor blackColor] setStroke];
    rectanglePath.lineWidth = 1;
    [rectanglePath stroke];
    
    
    //// outerRing Drawing
    UIBezierPath* outerRingPath = [UIBezierPath bezierPathWithOvalInRect:
                                   CGRectMake(CGRectGetMidX(rect) - 80,
                                              CGRectGetMidY(rect) - 80,
                                              160,
                                              160)];
    [innerCircleColor2 setFill];
    [outerRingPath fill];
    
    ////// outerRing Inner Shadow
    CGRect outerRingBorderRect = CGRectInset([outerRingPath bounds], -shadowBlurRadius, -shadowBlurRadius);
    outerRingBorderRect = CGRectOffset(outerRingBorderRect, -shadowOffset.width, -shadowOffset.height);
    outerRingBorderRect = CGRectInset(CGRectUnion(outerRingBorderRect, [outerRingPath bounds]), -1, -1);
    
    UIBezierPath* outerRingNegativePath = [UIBezierPath bezierPathWithRect: outerRingBorderRect];
    [outerRingNegativePath appendPath: outerRingPath];
    outerRingNegativePath.usesEvenOddFillRule = YES;
    
    CGContextSaveGState(context);
    {
        CGFloat xOffset = shadowOffset.width + round(outerRingBorderRect.size.width);
        CGFloat yOffset = shadowOffset.height;
        CGContextSetShadowWithColor(context,
                                    CGSizeMake(xOffset + copysign(0.1, xOffset), yOffset + copysign(0.1, yOffset)),
                                    shadowBlurRadius,
                                    shadow.CGColor);
        
        [outerRingPath addClip];
        CGAffineTransform transform = CGAffineTransformMakeTranslation(-round(outerRingBorderRect.size.width), 0);
        [outerRingNegativePath applyTransform: transform];
        [[UIColor grayColor] setFill];
        [outerRingNegativePath fill];
    }
    CGContextRestoreGState(context);
    
    [borderCircle setStroke];
    outerRingPath.lineWidth = 1;
    [outerRingPath stroke];
}

@end
